JuiColors class abstract
Constructors
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited
Constants
- black → const MaterialColor
- error → const MaterialColor
- gray → const MaterialColor
- noColor → const Color
- primaryColor → const MaterialColor
- primarySwatch → const MaterialColor
- Paleta de cores primárias
- secondaryColor → const MaterialColor
- success → const MaterialColor
- tertiaryColor → const MaterialColor
- warning → const MaterialColor
- white → const Color